###########################
django_seleniumhelpers
###########################

Extends ``django.test.LiveServerTestCase`` to simplify selenium webdriver testing.

Docs are available here: http://readthedocs.org/docs/django_seleniumhelpers/en/latest/
